from pipowl.lang import LangOwl

lang = LangOwl()

corpus = [
    "我今天真的好累",
    "我想趕快回家休息",
    "我現在只想躺在床上",
    "我還有好多事情沒做完",
    "我覺得壓力有點大",
    "我打算等一下喝杯咖啡",
    "我今天心情還不錯",
    "我想出去走走放鬆一下",
    "我有點餓，想吃點東西",
    "我覺得今天狀態不太好",
    "今天的天氣真的很好",
    "我覺得心情被影響到了",
    "我不太想跟別人說話",
    "我覺得自己需要一點安靜",
    "我想專心把事情做完",
    "我今天效率有點低",
    "我覺得需要找人聊聊天",
    "我有點想哭，但不知道為什麼",
    "我覺得今天還可以再撐一下",
    "我想早點睡，讓自己恢復一下"
]

results = lang.topk("我今天真的很想睡覺，因為工作太累了", corpus, k=3)

for text, score in results:
    print(f"{score:.3f} | {text}")
